const AWS = require('aws-sdk')
const _ = require('lodash')

module.exports = async ({ name, region }) => {
  const CloudWatchLogs = new AWS.CloudWatchLogs({region})
  const params = {
    logGroupName: `/aws/lambda/${name}`,
    descending: true,
    limit: 50,
    orderBy: 'LastEventTime'
  }

  const reply = await CloudWatchLogs.describeLogStreams(params).promise()

  if (!reply || reply.logStreams.length === 0) {
    throw new Error('function has no logs')
  }

  return _.chain(reply.logStreams)
    .filter(stream => stream.logStreamName.includes('[$LATEST]'))
    .map('logStreamName')
    .value()
}
