const AWS = require('aws-sdk')
const BbPromise = require('bluebird')

const createRole = async (name, service, region) => {
  const IAM = new AWS.IAM({ region })
  const assumeRolePolicyDocument = {
    Version: '2012-10-17',
    Statement: {
      Effect: 'Allow',
      Principal: {
        Service: service
      },
      Action: 'sts:AssumeRole'
    }
  }
  const roleRes = await IAM.createRole({
    RoleName: name,
    Path: '/',
    AssumeRolePolicyDocument: JSON.stringify(assumeRolePolicyDocument)
  }).promise()

  await IAM.attachRolePolicy({
    RoleName: name,
    PolicyArn: 'arn:aws:iam::aws:policy/AdministratorAccess'
  }).promise()

  await BbPromise.delay(15000)

  return roleRes.Role.Arn
}

module.exports = async (name, service, region) => {
  const IAM = new AWS.IAM({ region })

  let roleArn

  try {
    const res = await IAM.getRole({
      RoleName: name
    }).promise()
    roleArn = res.Role.Arn
  } catch (e) {
    if (e.message.includes('Role not found')) {
      roleArn = await createRole(name, service, region)
    } else {
      throw e
    }
  }
  return roleArn
}
